@@ -33,11 +33,28 @@ class DiskUpdate(ModuleUpdateBase):
 
     async def update_partitions(self) -> None:
         """Update partitions"""
+        device_list = []
+        partition_list = []
         for partition in self._disk.partitions():
+            if partition.device not in device_list:
+                device_list.append(partition.device)
+            partition_list.append(partition.mountpoint)
             for key, value in partition._asdict().items():
                 self._database.write(
-                    "disk", f"partitions_{partition.mountpoint}_{key}", value
+                    "disk",
+                    f"partitions_{partition.mountpoint}_{key}",
+                    value,
                 )
+        self._database.write(
+            "disk",
+            "devices",
+            str(device_list).replace("\\\\", "\\"),
+        )
+        self._database.write(
+            "disk",
+            "partitions",
+            str(partition_list).replace("\\\\", "\\"),
+        )
 
     async def update_usage(self) -> None:
         """Update usage"""
