@@ -73,8 +73,14 @@ class DisplayUpdate(ModuleUpdateBase):
 
     async def update_all_data(self) -> None:
         """Update data"""
+
+        # Clear table in case of hardware changes since last run
+        self._database.clear_table("display")
+
+        display_list = []
         for display_name in self._display.get_displays(self._database):
             display_key = make_key(display_name)
+            display_list.append(display_key)
             await asyncio.gather(
                 *[
                     self.update_name(display_key, display_name),
@@ -84,3 +90,4 @@ class DisplayUpdate(ModuleUpdateBase):
                     self.update_resolution_vertical(display_key),
                 ]
             )
+        self._database.write("display", "displays", str(display_list))
